Assets
======

.. automodule:: financepype.assets.spot
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: financepype.assets.contract
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: financepype.assets.blockchain
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: financepype.assets.factory
   :members:
   :undoc-members:
   :show-inheritance:
